% ------------------------------------------------------------ %
% PURPOSE: This program is written to generate some guesses    %
%	   for the parameters and then compute the GMM	       %
%	   objective function at these guesses.  The point is  %
%	   to try and figure out some decent initial starting  %
%	   values to begin a series minimization exercise.     %
% ------------------------------------------------------------ %

% This program has been modified to tackle the case where the we
% estimate the model for r&d firms only.  This may not require much
% changes to the code.

clear;
tic;
addpath ../Model;
addpath ../Quad;
addpath ../Simul;
addpath ../basic;
warning('off', 'Matlab:log:logOfZero');

% Determine the size of the maximum computations
maxeval = 500000;

% Load in the parameters from the data;
load ../Data/moments_chips;

mompick = [1 2 4 5 6 7 8 9 10 11 12 15 16];

data_vals{1} = moms(mompick);
data_vals{2} = n;
data_vals{3} = phi(mompick, mompick); 
data_vals{4} = 0;
data_vals{5} = 0.697;

% Define the matrices to be used as inputs
% Set the parameters we do not optimize over
delta = 0.177;
beta = 1/1.04;
srate = 0.025; 

% Here we need to specify tax rates for r&d and non-r&d firms.
trat_rd = 0.342;

% Parameters about the function call to solve for the steady state
sim_ind = 51;  %51

% Panel stuff (keep it small for now)
nFirms = 684;
nYears = 100; 

% Put stuff together;
fix_paras = [beta delta sim_ind nFirms nYears trat_rd srate];

% Start with a guess for the initial value
a = 6.8510;        %a = 8;      
b = 0.6480;        %b = 2;      
theta = 0.4570;    %
nu = 0.2503;	   %
rho = 0.6020;      %rho = .35;  
sig = 0.3980;      %sig = .25;  
lambda = 0.2080;   %lambda = .4;
gamma = 0.8430;    %gamma = .4; 
fc = 0.329;
   
% Put it together
readopt = 1;
if readopt == 1;
    load xop;
    guess_p = xopt';
else 
    guess_p = [theta rho sig lambda a b gamma fc];
end

% Here we define all the other stuff needed for SA to work
objfun = 'GMMObj_SA';	       % GMM Objective function
np = 8;			       % 8 parameters to be estimated	 
minmax = -1;		       % Minimize criterion
rt = 0.90;		       % Temperature decreasing rate
ns = 10;		       % Number of cycles before changing VM
nt = 10;		       % Number of cycles before changint T
neps = 3;		       % Number of big loops with no imp.
c = 2;			       % Parameter for next step selection
itemp = 1e2;		       % Initial temperature
nmom = 13;		       % Number of moments 
eps = 1e-9;		       % Degree of accuracy from the simulation 

% We want upper and lower bounds for the parameters;
% This is a bit of guess work here
up_b= [0.85 0.8 .7 2 18 10 1 1];
low_b = [0.3 0.3 0.10 0 1e-5 0 0 0];
 
% Initial step matrix - this should be mostly meaningless
vm = [.25 .25 .25 .25 .25 10 5 .2];

% Now we courageously call the SA program
[opt_point, opt_fval, nacc, nfeval, nobd, ftemp, vmfin, ier, xd, msim, diag, fs] = ...
	 SimAnneal_RD(objfun, np, guess_p, fix_paras, data_vals, minmax, rt, eps, ...
                      ns, nt, neps, maxeval, low_b, up_b, c, itemp, vm, nmom);

% Lets see the final time for it to run
toc

% Lets just be lazy and dump the entire output
save results_chips1.mat;
