% ------------------------------------------------------------ %
% PURPOSE:  This program is written primarily to test the code %
%	    for solving the value function and obtaining a set %
%	    of simulated data.  Some parts of this might feed  %
%	    up to another program which will tackle the issue  %
%	    of obtaining Simulated method of moments point     %
%	    estimates.					       %
% ------------------------------------------------------------ %

clear;
addpath ../Model/
addpath ../Simul/
addpath ../Quad/
addpath ../basic

% Initialize the variables of interest
readopt = 1;
if readopt == 1
    load xop;
    theta = xopt(1);
    rho = xopt(2);
    sigma = xopt(3);
    lambda = xopt(4);
    a = xopt(5);
    b = xopt(6);
    gamma = xopt(7);
    fc = xopt(8);
else 
    theta = 0.4583; 
    % nu = 0.1;54;  
    mu = -0.30;
    rho = 0.5727;
    sigma = 0.6040;
    lambda = 0.1714;
    a = 4.9791;
    b = 0.8616;
    gamma = 0.4900;
    fc = 0.4297; 
end
mu = -0.3;
alph = 1/3;
nu = alph*(1-theta)/(theta + alph*(1-theta));
sbar = 0.695;

% Other parameters
delta = .177;
beta = 1/1.04;
trat_rd = 34.2/100;
srate = 0.025;

% Panel stuff (keep it small for now)
nFirms = 684;
nYears = 100;

% Initialize v at zero to start things off
load gmat;
ginit = g;

% Write out the size of the simulated sample file
nsim = 50*nFirms;

% Choose the moments we are matching
mompick = [1 2 4 5 6 7 8 9 10 11 12 15 16];

% Call the value function to solve for firm value
[g, q, qd, i, r, kr, z, kg, w] = ValFun_Spill(theta, nu, mu, rho, sigma, lambda, a, b, ...
                            beta, delta, gamma, fc, trat_rd, sbar, srate, ginit);

% Now we can call the simulation program for firms with r&d spending
[zp, kp, qp, ip, rp, dp, pip, pir, sp, yp, sgp, fsp, succ, countz] = ...
         SimPanel(g, q, i, r, kr, z, kg, w, nFirms, nYears, theta, nu, mu, rho, ...
                  sigma, lambda, a, b, trat_rd, sbar, beta, delta, gamma, fc, srate);

% Here we can analyse the results by making a combined set of
% policy function matrices
zm = [zp(51:end,:)];
km = [kp(51:end,:)];
im = [ip(51:end,:)];
qm = [qp(51:end,:)];
pim = [pip(51:end,:)];
prm = [pir(51:end,:)];
dm = [dp(51:end,:)];
sm = [succ(51:end,:)];
rpm = [rp(51:end,:)];
rsm = [rp(51:end,:)./yp(51:end,:)];
sgm = [sgp(51:end,:)];
ym = [yp(51:end,:)];
fsm = [fsp(51:end,:)];

% Lets forget about all the stupid stuff and construct the actual
% moments of interest from the simulated data.  

% Do the moments for r&d
fm_rd = mean(vec(rsm));
std_rd = sqrt(mean(vec(rsm.^2)) - fm_rd^2);

% Pick up the sales to capital ratio
fm_sk = mean(vec(ym));

% Do the same for the fixed costs
fm_fs = mean(vec(fsm));

% Do the moments for q
fm_q = mean(vec(qm));
std_q = std(vec(qm),1);

% Do the moments for income after rd
fm_pr = mean(vec(prm));
std_pr = sqrt(mean(vec(prm.^2)) - fm_pr^2);

% Now we want investment
fm_i = mean(vec(im));
std_i = sqrt(mean(vec(im.^2)) - fm_i^2);

% Carry out the regression for income
beta_inc = reg(vec(prm(2:end,:)), adc(vec(prm(1:end-1,:))));
rho_pr = beta_inc(2);

% Compute the auto-regressive term for r&d
beta_rd = reg(vec(rsm(2:end,:)), adc(vec(rsm(1:end- ...
                                                  1,:))));
rho_rd = beta_rd(2);

% Autoregression for investment
beta_inv = reg(vec(im(2:end,:)), adc(vec(im(1:end-1,:))));
rho_inv = beta_inv(2);

% Pick up a regression of sales growth on R&D
beta_sg = reg(vec(sgm(2:end,:)), adc(vec(rsm(1:end-1,:))));
reg_sg = beta_sg(2);

% Pick up some correlation matrices
co_rdinv = mycorr(rsm(:), im(:));
co_rdq = mycorr(rsm(:), qm(:));
co_qi = mycorr(qm(:), im(:));
co_sglrd = mycorr(vec(sgm(2:end,:)), vec(rsm(1:end-1,:)));
co_rdk = mycorr(rsm(:), log(km(:)));

% We need the mean of sales growth elsewhere
fm_sg = mean(sgm(:));

% Put everything together into a big matrix
mom_sim = [fm_rd std_rd fm_sk fm_fs fm_q fm_pr std_pr std_i ...
           rho_pr rho_rd rho_inv co_rdinv co_rdq co_rdk co_qi co_sglrd];

% Load in the moments from the actual data
load ../Data/moments_chips.mat;

% Pick out the moments we want
mom_simp = mom_sim(mompick);
momsp = moms(mompick);
phip = phi(mompick, mompick);

disp 'Actual data moments on r&d, sales, q, earn and inv'
momsp
disp 'Simulated moments'
mom_simp

% Pick up the differences
mom_diff = momsp - mom_simp;
gmm_v = n*mom_diff *inv(n*phip)*mom_diff'

disp 'GMM function value'
gmm_v

% We need the residuals of the regressions
res_rd = rsm(2:end,:) - beta_rd(1) - beta_rd(2)*rsm(1:end-1,:); 
res_pr = prm(2:end,:) - beta_inc(1) - beta_inc(2)*prm(1:end-1,:);
res_inv = im(2:end,:) - beta_inv(1) - beta_inv(2)*im(1:end-1,:);

% Now we proceed to compute the weighting matrix as with the actual
% data. 
ri_fmrd = (rsm(:) - fm_rd);
ri_stdrd = (rsm(:).^2 - fm_rd^2 - std_rd^2)/(2*std_rd);

ri_rhord = rsm(1:end-1,:).*res_rd;
ri_rhord = vec([zeros(1, nFirms); ri_rhord]);

ri_fmq = (qm(:) - fm_q);

ri_fmfs = (fsm(:) - fm_fs);

ri_fmpr = (prm(:) - fm_pr);
ri_stdpr = (prm(:).^2 - fm_pr^2 - std_pr^2)/(2*std_pr);

ri_rhopr = prm(1:end-1,:).*res_pr;
ri_rhopr = vec([zeros(1, nFirms); ri_rhopr]);

ri_rhoinv = im(1:end-1,:).*res_inv;
ri_rhoinv = vec([zeros(1, nFirms); ri_rhoinv]);

ri_stdinv = (im(:).^2 - fm_i^2 - std_i^2)/(2*std_i);

ri_cordinv = (im(:).*rsm(:) - fm_rd*fm_i)/(std_rd*std_i) - co_rdinv;
ri_cordq = (qm(:).*rsm(:) - fm_q*fm_rd)/(std_rd*std_q) - co_rdq;
ri_coinvq = (qm(:).*im(:) - fm_q*fm_i)/(std_i*std_q) - co_qi;
ri_cosglrd = (rsm(1:end-1,:).*sgm(2:end,:) - fm_rd*fm_sg)/...
	     (std(vec(rsm(1:end-1,:)), 1)*std(vec(sgm(2:end,:)), 1)) - co_sglrd;
ri_cosglrd = vec([zeros(1, nFirms); ri_cosglrd]);

% Now we want to compute the Q matrices for each moment and then 
% derive the influence functions.  This will be done on a regressor
% by regressor basis. 

Q_iota = 1;
Q_lpr = mean(vec(prm(1:end-1,:).^2));
Q_linv = mean(vec(im(1:end-1,:).^2));
Q_lrds = mean(vec(rsm(1:end-1,:).^2));

% Now we can construct the influence functions.  We will be doing
% this on a moment by moment basis.
phi_fmrd = inv(Q_iota)*ri_fmrd;
phi_stdrd = inv(Q_iota)*ri_stdrd;

phi_rhord = inv(Q_lrds)*ri_rhord;

phi_fmq = inv(Q_iota)*ri_fmq;

phi_fmfs = inv(Q_iota)*ri_fmfs;

phi_fmpr = inv(Q_iota)*ri_fmpr;
phi_stdpr = inv(Q_iota)*ri_stdpr;

phi_rhopr = inv(Q_lpr)*ri_rhopr;
phi_rhoinv = inv(Q_linv)*ri_rhoinv;

phi_stdinv = inv(Q_iota)*ri_stdinv;

phi_cordinv = inv(Q_iota)*ri_cordinv;
phi_coinvq = inv(Q_iota)*ri_coinvq;
phi_cosglrd = inv(Q_iota)*ri_cosglrd;

% Now we stack all the influence functions and take their inner
% product.  This will give us the asymptotic covariance matrix for
% the moments.
phimat_s = [phi_fmrd phi_stdrd phi_fmfs phi_fmq phi_fmpr ...
          phi_stdpr phi_stdinv phi_rhopr phi_rhord phi_rhoinv ...
	  phi_cordinv phi_coinvq phi_cosglrd];

phi_s = (phimat_s'*phimat_s)/nsim;
sqrt(diag(phi_s)/nsim)

% Save the matrix containing the data on the moments.
svfil = 'simmoments_chips';
save(svfil, 'mom_simp', 'phi_s', 'nsim');
