#delimit;

* Do the initial set up including using semicolons as a delimiter;

clear all;
set mem 2000m;
adopath + ../basic;

use ../Analysis/captots;

* Take a quick peek to make sure that our year variables work ok;
sum yeara, d;

* Turn the data set into a panel;
tsset gvkey yeara;

* Plus take out the industries we dont want here;
drop if strmatch(ff_indus49, "Softw") == 0;

* Make a size variable - log fixed assets;
gen siz = log(mean_rppe);

* Pick up operating costs;
gen fc_sales = (sga_ex - rd)/sales_net;

* Construct a sales growth measure;
gen sgrow = real_sales/L.real_sales - 1;

* We want to adjust some outliers for sales growth;
replace sgrow = -.5 if sgrow < -.5;
replace sgrow = 1 if sgrow > 1 & sgrow <.;
sum sgrow, d;

* This step demeans the data at the firm level;
center rd_sales mq roa inv_k sgrow, meansave;
sort gvkey;
by gvkey: center rd_sales mq roa inv_k sgrow, replace;

replace rd_sales = c_rd_sales + m_rd_sales;
replace mq = c_mq + m_mq;
replace roa = c_roa + m_roa;
replace inv_k = c_inv_k + m_inv_k;
replace sgrow = c_sgrow + m_sgrow;

* Remove the centered variables;
sum rd_sales c_rd_sales m_rd_sales;
drop c_* m_*;

sort gvkey yeara;

* Here we want to be able to have lagged cash flow as well;
gen lroa = L.roa;

* Now lets pickup lagged rd_k - this could be a bit tricky;
gen lrd_sales = L.rd_sales;

* Here we will be picking up lagged investment;
gen linv_k = L.inv_k;

* Now that we have lagged cash flows, we can get rid of 1984 data;
* Comment out for now;
drop if yeara <= 1984;

* Lets look at the data a bit;
sum rd_sales sales_k inv_k roa mq, d;

* This tackles outliers for fixed costs;
winsor fc_sales, gen(wfc_sales) p(0.01);

* Now we'll run some regressions;
reg rd_sales lrd_sales;
reg roa lroa;
reg sgrow lrd_sales;

* Next thing to do is to count the number of firm years;
sort gvkey;
by gvkey: egen numf = count(gvkey);

* The final step is to adjust for firm and year fixed effects;
* I hope this will be tackled correctly here - It's kind of tricky;

* This part of the code will be about computing tax rates;
* We will do this using aggregate values at an annual basis;
sort year;
by year: egen sy_tax = sum(taxes);
by year: egen sy_sga = sum(sga_ex);
by year: egen sy_rd = sum(rd);
by year: egen sy_ppe = sum(mean_rppe);
by year: egen sy_earn = sum(earn);
by year: egen sy_depr = sum(depr);
by year: egen sy_sales = sum(sales_net);
gen sy_fc = (sy_sga - sy_rd)/sy_sales;
gen sy_trate = sy_tax/(sy_earn - sy_depr);
sum sy_trate, d;
sum sy_fc, d;

* Time to write this data out;
sort gvkey yeara;
outsheet gvkey yeara siz rd_sales lrd_sales sales_k sgrow mq roa lroa
      inv_k linv_k wfc_sales using softwdata.txt, replace;
