% ------------------------------------------------------------ %
% PURPOSE: This program is written to make a table with all    %
% 	   the results from the different experiments. We are  %
%	   going to focus on the tax experiment, and the       %
%	   increase in patent rights.  Its not yet clear what  %
%	   the best way of presenting these results are.       %
% ------------------------------------------------------------ %

clear;

% Now we read in the results from the different experiments
load ExperVals;

% Lets get the data we want in the shapes we want
subs_dat(1,:) = rd_simdata;
subs_dat(2,:) = bsv_simdata;
subs_dat(3,:) = chp_simdata;
subs_dat(4,:) = hdw_simdata;
subs_dat(5,:) = med_simdata;
subs_dat(6,:) = phrm_simdata;
subs_dat(7,:) = sft_simdata;

% Now we make the tables
substab = 'expersubs.txt';

% We need indices to print
subindx = [3:4 2 6:7 5];

% We also need to specify all the table variables and names
inddescs = strvcat('\\emph{All firms}', 'Business services', 'Chips', ...
                   'Hardware', 'Medical equipment', 'Pharmaceuticals', ...
                   'Software');

% Now we'll proceed to make the tables
% Here we need to pick and choose which moments to print
fid = fopen(substab, 'w');

% Write the headers
fprintf(fid, '\\begin{tabular}{p{.3cm}lccccccccc} \\\\ \n');
fprintf(fid, '\\hline \n');
fprintf(fid, ['& & $\\tau_{rd}$ & \\multicolumn{2}{c}{\\$1.00 impact} & & \\multicolumn{4}{c}{Steady-state averages} ' ...
              '\\\\ \n']);
fprintf(fid, '\\cline{4-5} \\cline{7-10} \n')
fprintf(fid, [' & & & Short-run & Steady- & & R\\&D to &  profitability ' ...
              '& Tobin''s q & Success \\\\ \n']);
fprintf(fid, ' & & & & state & & sales & & & rate \\\\ \n');
fprintf(fid, '\\hline \n');
	  
% Here we just write the results
for i = 1:7
    fprintf(fid, strcat('\\multicolumn{7}{l}{', inddescs(i, :), '} \\\\ \n'));
    fprintf(fid, ['& Experiment & %3.2f & \\$%3.2f & \\$%3.2f & & %4.3f ' ...
                  '& %4.3f & %4.3f & %4.3f \\\\ \n'], 0.05, subs_dat(i, subindx));
    if i < 2
        fprintf(fid, '\\\\ \n');
        fprintf(fid, '\\multicolumn{5}{l}{\\emph{Selected industries}} \\\\ \n');
    end
end

% Now we want to close the table
fprintf(fid, '\\hline \n');
fprintf(fid, '\\end{tabular} \n');
fclose(fid)

return;
