% ------------------------------------------------------------ %
% PURPOSE: This program is written to evaluate the impact of   %
%	   exogeneous changes in some of the key parameters on %
%	   the simulated moments and other key parameters of   %
%	   the model. The main focus will be on the impact of  %
%	   these changes on the r&d sector.  Similar exercises %
%	   will be carried out for the extended models and the %
%          final results will be tabulated in a short tables.  %  
% ------------------------------------------------------------ %

clear;
tic;
addpath ../Model;
addpath ../Quad;
addpath ../Simul;
addpath ../BusSrv;
addpath ../basic;
% warning('off', 'Matlab:log:logOfZero');

% Load in the parameters from the data;
load ../Data/moments_bussrv;
load gmat;

mompick = [1 2 4 5 6 7 8 9 10 11 12 15 16];

data_vals{1} = moms(mompick);
data_vals{2} = n;
data_vals{3} = phi(mompick, mompick);
data_vals{4} = g;
data_vals{5} = 0.803;

% Define the matrices to be used as inputs
% Set the parameters we do not optimize over
fc = 0.3902;
delta = 0.176;
beta = 1/1.04;
srate = 0.025;         % This will be modified later
acc = 0.01;	       % Accuracy of fit

% Parameters about the function call to solve for the steady state
sim_ind = 51;  %51

% We also want to pick up tax data
trat_rd = 0.342;

% Panel stuff (keep it small for now)
nFirms = 154; 
nYears = 100;  

% Put stuff together;
fix_paras = [beta delta sim_ind nFirms nYears trat_rd srate];

% Start with a guess for the initial value
nu = 0.3429;
theta = 0.4400;
mu = -0.30;
rho = 0.5746;
sigma = 0.5440;
lambda = 0.1952;
a = 3.8564;
b = 0.7715;
gamma = 0.5157;
  
% Put it together
readopt = 1;
if readopt == 1
    load ../BusSrv/xop;
    guess_p = xopt';
else
    guess_p = [theta rho sig lambda a b gamma fc];
end

% Here we define all the other stuff needed for SA to work
objfun = 'GMMObj_mod';	       % GMM Objective function

global fixgrid
fixgrid = -1;

% This part calls the computations using the solved values
[fval, moms, ex_diags, grd] = feval(objfun, guess_p, fix_paras, data_vals);

%% Lets call it again with a new set of initial value functions
m = 0;
while abs(data_vals{5} - ex_diags(2)) > acc
      data_vals{4} = grd;
      data_vals{5} = (data_vals{5}+ex_diags(2))/2;
      [fval, moms, ex_diags, grd] = feval(objfun, guess_p, fix_paras, data_vals);
      m = m + 1
end

muk = ex_diags(3);

% Lets save the fix cost and pass it along the next time - overwrite this if we want to
% data_vals{8} = sfc;

fixgrid = 1;

% Here we start tinkering with a subsidy for tax rates - start with 5%
sub_rate = 0.05;

% Lets update the parameter set 
fix_paras_sub = [beta delta sim_ind nFirms nYears trat_rd sub_rate];

% Redefine the data values
data_valssub = data_vals;

% Call the function to test things 
[fvalsub, momssub, ex_diagssub, grd] = feval(objfun, guess_p, fix_paras_sub, data_vals);

%% Lets call it again with a new set of initial value functions
m = 0;
while abs(data_valssub{5} - ex_diagssub(2)) > acc
      data_valssub{4} = grd;
      data_valssub{5} = (data_valssub{5}+ex_diagssub(2))/2;
      [fvalsub, momssub, ex_diagssub, grd] = feval(objfun, guess_p, fix_paras_sub, data_valssub);
      m = m + 1
end

% Put together the data we want to report
subdollar = [momssub(1) - moms(1)]/(momssub(1)*srate);
bsv_simdata = [moms(1) momssub(1) moms(16) subdollar momssub(17) momssub(5) momssub(4)];

svfil = 'ExperVals';
save(svfil, 'bsv_simdata', '-append');
