% ------------------------------------------------------------ %
% PURPOSE:  This program is written primarily to test the code %
%	    for solving the value function and obtaining a set %
%	    of simulated data.  Some parts of this might feed  %
%	    up to another program which will tackle the issue  %
%	    of obtaining Simulated method of moments point     %
%	    estimates.					       %
% ------------------------------------------------------------ %

clear;
addpath ../Model/
addpath ../Simul/
addpath ../Quad/
addpath ../basic

% Initialize the variables of interest
readopt = 0;
if readopt == 1
    load xop;
    theta = xopt(1);
    rho = xopt(2);
    sigma = xopt(3);
    lambda = xopt(4);
    a = xopt(5);
    b = xopt(6);
    gamma = xopt(7);
    fc = xopt(8);
else
    theta = 0.4313; 
    % nu = 0.1;54;  
    rho = 0.6456;
    sigma = 0.3423;
    lambda = 0.2338;
    a = 4.0149;
    b = 0.6598;
    gamma = 0.3625;
    fc = 0.3611; 
end
mu = -0.30;
alph = 1/3;
nu = alph*(1-theta)/(theta + alph*(1-theta));
sbar = 0.806;

% Other parameters
delta = .189;
beta = 1/1.04;
trat_rd = 30.9/100;
srate = 0.025;

% Panel stuff (keep it small for now)
nFirms = 3366;
nYears = 100;

% Initialize v at zero to start things off
load gmat;
ginit = g; 
ginit = 0;

% Choose the moments we are matching
mompick = [1 2 4 5 6 7 8 9 10 11 12 15 16];

% We'll tweak the program and see
% gamma = gamma*1.025;

% Call the value function to solve for firm value
[g, q, qd, i, r, kr, z, kg, w] = ValFun_Spill(theta, nu, mu, rho, sigma, lambda, a, b, ...
                            beta, delta, gamma, fc, trat_rd, sbar, srate, ginit);

% Now we can call the simulation program for firms with r&d spending
[zp, kp, qp, ip, rp, dp, pip, pir, sp, yp, sgp, fsp, succ, countz] = ...
         SimPanel(g, q, i, r, kr, z, kg, w, nFirms, nYears, theta, nu, mu, rho, ...
                  sigma, lambda, a, b, trat_rd, sbar, beta, delta, gamma, fc, srate);

% Here we can analyse the results by making a combined set of
% policy function matrices
zm = [zp(51:end,:)];
km = [kp(51:end,:)];
im = [ip(51:end,:)];
qm = [qp(51:end,:)];
pim = [pip(51:end,:)];
prm = [pir(51:end,:)];
dm = [dp(51:end,:)];
sm = [succ(51:end,:)];
rpm = [rp(51:end,:)];
rsm = [rp(51:end,:)./yp(51:end,:)];
sgm = [sgp(51:end,:)];
ym = [yp(51:end,:)];
fsm = [fsp(51:end,:)];

% Lets forget about all the stupid stuff and construct the actual
% moments of interest from the simulated data.  

% Do the moments for r&d
fm_rd = mean(vec(rsm));
std_rd = sqrt(mean(vec(rsm.^2)) - fm_rd^2);

% Pick up the sales to capital ratio
fm_sk = mean(vec(ym));

% Do the same for the fixed costs
fm_fs = mean(vec(fsm));

% Do the moments for q
fm_q = mean(vec(qm));

% Do the moments for income after rd
fm_pr = mean(vec(prm));
std_pr = sqrt(mean(vec(prm.^2)) - fm_pr^2);

% Now we want investment
fm_i = mean(vec(im));
std_i = sqrt(mean(vec(im.^2)) - fm_i^2);

% Carry out the regression for income
prdiff = prm;
beta_inc = reg(vec(prdiff(2:end,:)), adc(vec(prdiff(1:end-1,:))));
rho_pr = beta_inc(2);

% Compute the auto-regressive term for r&d
beta_rd = reg(vec(rsm(2:end,:)), adc(vec(rsm(1:end- ...
                                                  1,:))));
rho_rd = beta_rd(2);

% Autoregression for investment
beta_ik = reg(vec(im(2:end,:)), adc(vec(im(1:end-1,:))));
rho_ik = beta_ik(2);

% Pick up a regression of sales growth on R&D
beta_sg = reg(vec(sgm(2:end,:)), adc(vec(rsm(1:end-1,:))));
reg_sg = beta_sg(2);

% Pick up some correlation matrices
co_rdinv = mycorr(rsm(:), im(:));
co_rdq = mycorr(rsm(:), qm(:));
co_qi = mycorr(qm(:), im(:));
co_sglrd = mycorr(vec(sgm(2:end,:)), vec(rsm(1:end-1,:)));
co_rdk = mycorr(rsm(:), log(km(:)));

% Put everything together into a big matrix
mom_sim = [fm_rd std_rd fm_sk fm_fs fm_q fm_pr std_pr std_i ...
           rho_pr rho_rd rho_ik co_rdinv co_rdq co_rdk co_qi co_sglrd];

% Load in the moments from the actual data
load ../Data/moments_hardw.mat;

% Put in an adjustment for the simulated data
load simmoments_hardw;
momsp = mom_simp;
phip = phi_s;

% Pick out the moments we want
mom_simp = mom_sim(mompick);
% momsp = moms(mompick);
% phip = phi(mompick, mompick);

disp 'Actual data moments on r&d, sales, q, earn and inv'
momsp
disp 'Simulated moments'
mom_simp

% Pick up the differences
mom_diff = momsp - mom_simp;
gmm_v = n*mom_diff *inv(n*phip)*mom_diff'

disp 'Moment difference'
mom_diff
disp 'Weighted moment difference'
wgt_diff = (inv(phip)*mom_diff')'

% Get a sense of the weighting matrix
wgtm = inv(phip);
nm = length(momsp);
for i = 1:nm;
    for j = 1:nm
        covm(i,j) = wgtm(i,j)/sqrt(wgtm(i,i)*wgtm(j,j));
    end
end

% % Pick up a hypothetical without a moment
% mom_dsh = [mom_diff(1:11) mom_diff(13:14)];
% phi_sh = [phi(1:11, 1:11) phi(1:11, 13:14); phi(13:14,1:11) phi(13:14,13:14)];
% 
% gmm_sh = n*mom_dsh*inv(n*phi_sh)*mom_dsh'
