% ------------------------------------------------------------ %
% PURPOSE:  This program is written to compile all the data    %
% 	    from the industry level estimation into text output%
%	    file(s).  We may need two files in order to fit    %
%	    it all onto 1 page.  Its a big annoying in that way%
%	    We do have a bunch of numbers to read in.  	       %
% ------------------------------------------------------------ %

clear;

% Read in the data files - this will be messy;
[alldat] = load('../RDOnly/simvals.mat');
[bussrvdat] = load('../BusSrv/simvals_bussrv.mat');
[chipsdat] = load('../Chips/simvals_chips.mat');
[hardwdat] = load('../Hardw/simvals_hardw.mat');
[medeqdat] = load('../Medeq/simvals_medeq.mat');
[pharmadat] = load('../Pharma/simvals_pharma.mat');
[softwdat] = load('../Softw/simvals_softw.mat');

% We probably want to stick to an alphabetical organization.
% This means we will go BusSrv, Chips, Hardw, Medeq, Softw and Pharma
points(1,:) = [alldat.xopt_dat]; 
points(2,:) = [bussrvdat.xopt_dat];
points(3,:) = [chipsdat.xopt_dat]; 
points(4,:) = [hardwdat.xopt_dat]; 
points(5,:) = [medeqdat.xopt_dat]; 
points(6,:) = [pharmadat.xopt_dat];
points(7,:) = [softwdat.xopt_dat]; 

simv(1,:) = alldat.xopt_sim;
simv(2,:) = bussrvdat.xopt_sim;
simv(3,:) = chipsdat.xopt_sim;
simv(4,:) = hardwdat.xopt_sim;
simv(5,:) = medeqdat.xopt_sim;
simv(6,:) = pharmadat.xopt_sim;
simv(7,:) = softwdat.xopt_sim;

% Name the files
indp = 'simparas.txt';

% Here we want to name the rows in each files
inddescs = strvcat('\\emph{All firms}', 'Business services', 'Chips', ...
                   'Hardware', 'Medical equipment', ...
                   'Pharmaceuticals', 'Software'); 

% The parameter file should be relatively easy to make
fid = fopen(indp, 'w');

% Write the headers
fprintf(fid, '\\begin{tabular}{p{.3cm}l*{8}{c}} \\\\ \n ');
fprintf(fid, '\\hline \n');
fprintf(fid, ['& Parameter & $\\theta$ & $\\rho$ & $\\sigma$ ' ...
              '& $\\lambda$ & $a$ & $b$ & $\\gamma$ & $fc$ ' ...
              '\\\\ \n']);
fprintf(fid, '\\hline \n');
	  
% Here we just write the results
for i = 1:7
    fprintf(fid, strcat('\\multicolumn{5}{l}{', inddescs(i, :), '} \\\\ \n'));
    fprintf(fid, ['& Actual data & %4.3f & %4.3f & %4.3f & %4.3f & %4.3f & %4.3f ' ...
                  '& %4.3f & %4.3f \\\\ \n'], [points(i,:)]);
    fprintf(fid, ['& Simulated data & %4.3f & %4.3f & %4.3f & %4.3f ' ...
                  '& %4.3f & %4.3f & %4.3f & %4.3f \\\\ \n'], ...
            simv(i, :));
    if i < 2
        fprintf(fid, '\\\\ \n');
        fprintf(fid, '\\multicolumn{5}{l}{\\emph{Selected industries}} \\\\ \n');
    end
end

% Now we want to close the table
fprintf(fid, '\\hline \n');
fprintf(fid, '\\end{tabular} \n');
fclose(fid)

return;
