% ------------------------------------------------------------ %
% PURPOSE:  This program is written to compile all the data    %
% 	    from the industry level estimation into text output%
%	    file(s).  We may need two files in order to fit    %
%	    it all onto 1 page.  Its a big annoying in that way%
%	    We do have a bunch of numbers to read in.  	       %
% ------------------------------------------------------------ %

clear;

% Read in the data files - this will be tricky;
[bussrvdat] = load('../BusSrv/bussrvdata.mat');
[chipsdat] = load('../Chips/chipsdata.mat');
[hardwdat] = load('../Hardw/hardwdata.mat');
[medeqdat] = load('../Medeq/medeqdata.mat');
[pharmadat] = load('../Pharma/pharmadata.mat');
[softwdat] = load('../Softw/softwdata.mat');

% We probably want to stick to an alphabetical organization.
% This means we will go BusSrv, Chips, Hardw, Medeq, Softw and Pharma
points(1,:) = [bussrvdat.points bussrvdat.psistat];
points(2,:) = [chipsdat.points chipsdat.psistat];
points(3,:) = [hardwdat.points hardwdat.psistat];
points(4,:) = [medeqdat.points medeqdat.psistat];
points(5,:) = [pharmadat.points pharmadat.psistat];
points(6,:) = [softwdat.points softwdat.psistat];

stderr(1,:) = [bussrvdat.stderr];
stderr(2,:) = [chipsdat.stderr ];
stderr(3,:) = [hardwdat.stderr ];
stderr(4,:) = [medeqdat.stderr ];
stderr(5,:) = [pharmadat.stderr];
stderr(6,:) = [softwdat.stderr ];

moms(1,:) = [bussrvdat.moms];
moms(2,:) = [chipsdat.moms ];
moms(3,:) = [hardwdat.moms ];
moms(4,:) = [medeqdat.moms ];
moms(5,:) = [pharmadat.moms];
moms(6,:) = [softwdat.moms ];

mom_sim(1,:) = [bussrvdat.mom_sim];
mom_sim(2,:) = [chipsdat.mom_sim ];
mom_sim(3,:) = [hardwdat.mom_sim ];
mom_sim(4,:) = [medeqdat.mom_sim ];
mom_sim(5,:) = [pharmadat.mom_sim];
mom_sim(6,:) = [softwdat.mom_sim ];

jbar(1,:) = [bussrvdat.jbar];
jbar(2,:) = [chipsdat.jbar ];
jbar(3,:) = [hardwdat.jbar ];
jbar(4,:) = [medeqdat.jbar ];
jbar(5,:) = [pharmadat.jbar];
jbar(6,:) = [softwdat.jbar ];

% Name the files
indp = 'indparas.txt';
indm = 'indmoms.txt';
indec = 'indecon.txt';

% Here we want to name the rows in each files
inddescs = strvcat('Business services', 'Chips', 'Hardware', ['Medical ' ...
                    'equipment'], 'Pharmaceuticals', 'Software'); 

% The parameter file should be relatively easy to make
fid = fopen(indp, 'w');

% Write the headers
fprintf(fid, '\\begin{tabular}{p{.3cm}l*{9}{c}} \\\\ \n ');
fprintf(fid, '\\hline \n');
fprintf(fid, ['& Parameter & $\\theta$ & $\\rho$ & $\\sigma$ ' ...
              '& $\\lambda$ & $a$ & $b$ & $\\gamma$ & $fc$ ' ...
              '& $\\hat{\\Psi}$ \\\\ \n']);
fprintf(fid, '\\hline \n');
	  
% Here we just write the results
for i = 1:6
    fprintf(fid, strcat('\\multicolumn{5}{l}{', inddescs(i, :), '} \\\\ \n'));
    fprintf(fid, ['& Estimate & %4.3f & %4.3f & %4.3f & %4.3f & %4.3f & %4.3f ' ...
                  '& %4.3f & %4.3f & %5.0f \\\\ \n'], [points(i,:)]);
    fprintf(fid, ['& Std. err. & (%4.3f) & (%4.3f) & (%4.3f) & (%4.3f) ' ...
                  '& (%4.3f) & (%4.3f) & (%4.3f) & (%4.3f) & \\\\ \n'], ...
            stderr(i, :));
    if i < 6
        fprintf(fid, '\\\\ \n');
    end
end

% Now we want to close the table
fprintf(fid, '\\hline \n');
fprintf(fid, '\\end{tabular} \n');
fclose(fid)

% This part will construct the table with the moments from the estimation.
% Here we need to pick and choose which moments to save.
fid = fopen(indm, 'w');

% Write the headers
fprintf(fid, '\\begin{tabular}{p{.3cm}lcccccccccc} \\\\ \n');
fprintf(fid, '\\hline \n');
fprintf(fid, ['& & & \\multicolumn{3}{c}{Averages} ' ...
              '& & \\multicolumn{2}{c}{Correlations between} ' ...
              '& & Success rate\\\\ \n']);
fprintf(fid, '\\cline{4-6} \\cline{8-9} \n')
fprintf(fid, [' & & & R\\&D to & profitability & Tobin''s q  ' ...
              ' & & lag R\\&D to sales & investment & &  ' ...
               '\\\\ \n']);
fprintf(fid, [' & & & sales & & & & sales growth & Tobin''s q ' ...
               '& & \\\\ \n']);
fprintf(fid, '\\hline \n');

% We need to pick up the moment indices
mom_indx = [1 5 4 12 13]; 
jb_indx = 2;
	  
% Here we just write the results
for j = 1:6
    fprintf(fid, strcat('\\multicolumn{5}{l}{', inddescs(j, :), '} \\\\ \n'));
    fprintf(fid, ['& Data & & %4.3f & %4.3f & %4.3f & & %4.3f & %4.3f ' ...
                  '& & \\\\ \n'], moms(j, mom_indx));
    simvals = [mom_sim(j, mom_indx) jbar(j, jb_indx)];
    fprintf(fid, ['& Model & & %4.3f & %4.3f & %4.3f & & %4.3f &  %4.3f ' ...
                  '& & %4.3f \\\\ \n'], simvals);
    if j < 6
        fprintf(fid, '\\\\ \n');
    end
end

% Now we want to close the table
fprintf(fid, '\\hline \n');
fprintf(fid, '\\end{tabular} \n');
fclose(fid)                            

return;
