% ------------------------------------------------------------ %
% PURPOSE:  This program is designed to construct the grid and %
%           transition matrix following the Tauchen and Hussey %
%           approximations for an AR(1) process.  This will    %
%           be used for numeric intergration in the calculation%
%           of various value functions.  This will take as an  %
%           input various parameters of the specification.     %
% ------------------------------------------------------------ %
% INPUTS:                                                      %
%           theta - constant term in AR(1) equation            %
%           rho   - auto-regressive term in AR(1) equation     %
%           sigma - conditional variance in AR(1) equation     %
%           n     - number of grid points to intergrate over   %
%                                                              %
% OUTPUTS:                                                     %
%           y     - grid points for continuous variable        %
%           T     - transition matrix over grid points         %
%           w     - weighting function for grid points         %
% ------------------------------------------------------------ %
% NOTES:                                                       %
%     The program is written using source code from Marco and  %
% his unknown RA.  I modified this code to use unconditional   %
% variances in both steps.  I'm still somewhat confused by     %
% whether this program uses unconditional or conditional       %
% values for sigma.                                            %
% ------------------------------------------------------------ %
% OWNERSHIP:                                                   %
% Written By: Missaka W.                                       %
% Date: 02/21/2007                                             %
% Last Update:                                                 %
% ------------------------------------------------------------ %
function [y, T, w] = QuadNorm(theta, rho, sigma, n)

%%% Calculate Gauss Hermit grid and weight
iteration=20000;            %%% Don't really know why this is needed
[x,w]=ghquad(n,iteration);  %%% routine to find Gauss Hermit grid and weight
y=sqrt(2)*sigma*x+theta/(1-rho)*ones(n,1); % Calculate corresponding y

%%% Calculate transition matrix
T=zeros(n,n);
for i=1:n %% (t)
    for j=1:n  %% (t+1)
        T(i,j)=exp(-(y(j)-theta-rho*y(i))^2/(2*sigma^2) ...
               +(y(j)-theta/(1-rho))^2/(2*sigma^2))*(1/pi)^0.5*w(j);
    end
end

%% Normalize each row
T1=sum(T,2)*ones(1,n);
T=T./T1;
T = T';

return;






