% This program was written to test our computation of the standard
% errors obtained under this estimation method.  Lets hope this
% will spit out some reasonable looking numbers.  The main thing
% here is that we need to estimate two matrices, described in the
% work by Gourieroux and Monfort.

% The first part of this exercise is to get a handle on the data

clear;
addpath ../basic;
addpath ../Data/;

% Define the input and output files for us to read and write
infile = 'maindata.txt';

% Time to read in the data
[gvkey, yeara, siz, rds, lrds, salek, sgrow, q, roa, lroa, invk, linvk] = ...
	textread(infile, '%f%f%f%f%f%f%f%f%f%f%f%f', 'emptyvalue', NaN, ...
			 'delimiter', '\t', 'headerlines', 1);

% Get the length of the data set
n = length(gvkey);
iota = ones(n, 1);

% Find out the observations with nonmissing values for lagged income
k = find(1-isnan(lroa));
dk = zeros(n, 1); dk(k) = 1;

% Do a similar thing for lagged r&d
j = find(1-isnan(lrds));
dj = zeros(n, 1); dj(j) = 1;

% Load in the moments as well
load moments.mat;

% Now we will calculate the derivative at the data point
derv = zeros(n, 13);

% Lets assign the input moments so that the code is easier to read
fm_rd = moms(1);
std_rd = moms(2);
fm_sk = moms(3);
fm_q = moms(4);
fm_roa = moms(5);
std_roa = moms(6);
std_i = moms(7);
rho_roa = moms(8);
rho_rd = moms(9);
cord_inv = moms(10);
cord_q = moms(11);
coinv_q = moms(12);
cosg_lrd = moms(13);

fm_inv = mean(invk);
std_q = std(q);
fm_lrd = mean(lrds(~isnan(lrds)));
fm_sg = mean(sgrow(~isnan(sgrow)));
std_lrd = std(lrds(~isnan(lrds)));
std_sg = std(sgrow(~isnan(sgrow)));

% The next part is simply a matter of carefully writing out the
% various functions which yields the derivatives of interest
derv(:,1) = - (vec(rds) - fm_rd) + (vec(rds.^2) - fm_rd^2 - ...
 	      std_rd^2)*2*fm_rd + (vec(rds) - fm_rd - ...
              rho_rd*(vec(lrds) - fm_rd))*(1-rho_rd) + ...
	      ((vec(rds.*invk) - fm_rd*fm_inv)/(std_rd*std_i) - cord_inv) ...
	      * fm_inv/(std_rd*std_i) + ...
	      ((vec(rds.*q) - fm_rd*fm_q)/(std_rd*std_q) - cord_q) ...
	      * fm_q/(std_rd*std_q);
derv(:,2) = - (vec(rds.^2) - fm_rd^2 - std_rd^2)*2*std_rd + ...;
	      ((vec(rds.*invk) - fm_rd*fm_inv)/(std_rd*std_i) - cord_inv) ...
	      .*(vec(rds.*invk) - fm_rd*fm_inv)/(std_rd^2*std_i)  + ...
	      ((vec(rds.*q) - fm_rd*fm_q)/(std_rd*std_q) - cord_q) ...
	      .*(vec(rds.*q) - fm_rd*fm_q)/(std_rd^2*std_q);
derv(:,3) = - (vec(salek) - fm_sk);
derv(:,4) = - (vec(q) - fm_q) + ...
	      ((vec(rds.*q) - fm_rd*fm_q)/(std_rd*std_q) - cord_q) ...
	      * fm_rd/(std_rd*std_q) + ...
	      ((vec(q.*invk) - fm_q*fm_inv)/(std_q*std_i) - coinv_q) ...
	      * fm_inv/(std_q*std_i);
derv(:,5) = - (vec(roa) - fm_roa) + (vec(roa.^2) - fm_roa^2 - ...
	      std_roa^2)*2*fm_roa + (vec(roa) - fm_roa - ...
              rho_roa*(vec(lroa) - fm_roa))*(1-rho_roa);
derv(:,6) = - (vec(roa.^2) - fm_roa^2 - std_roa^2)*2*std_roa;
derv(:,7) = - (vec(invk.^2) - fm_inv^2 - std_i^2)*2*std_i + ...
	      ((vec(rds.*invk) - fm_rd*fm_inv)/(std_rd*std_i) - cord_inv) ...
	      .*(vec(rds.*invk) - fm_rd*fm_inv)/(std_rd*std_i^2)  + ...
	      ((vec(invk.*q) - fm_inv*fm_q)/(std_i*std_q) - coinv_q) ...
	      .*(vec(invk.*q) - fm_inv*fm_q)/(std_i^2*std_q);
derv(:,8) = - ((vec(roa) - fm_roa) - rho_roa*(vec(lroa) - ...
                   fm_roa)).*(vec(lroa) - fm_roa);
derv(:,9) = - ((vec(rds) - fm_rd) - rho_rd*(vec(lrds) - ...
                   fm_rd)).*(vec(lrds) - fm_rd);
derv(:,10) = - (vec(rds.*invk) - fm_rd*fm_inv)/(std_rd*std_i) - cord_inv;
derv(:,11) = - (vec(rds.*q) - fm_rd*fm_q)/(std_rd*std_q) - cord_q;
derv(:,12) = - (vec(invk.*q) - fm_q*fm_inv)/(std_q*std_i) - coinv_q;
derv(:,13) = - (vec(lrds.*sgrow) - fm_lrd*fm_sg)/(std_lrd*std_sg) - cosg_lrd;

% Here we adjust for NaN problems in the data with lagged values
derv(~dj, 1) = 0;
derv(~dk, 5) = 0;
derv(~dk, 8) = 0;
derv(~dj, 9) = 0;
derv(~dj,13) = 0;

% Lets compute the cross produce matrix
derv_cross = derv'*derv;

% Lets construct a matrix of observations - do the lower diag only
% This is going to involve doing weird stuff with figuring out what
% parts of our observations involve zeros or not
dp = 1 - (derv == 0);
dpm = dp'*dp
dpm(dpm == 0) = 1;    % Quick adjustment for division by zero

derv_cross(dpm == 1);

% Compute the cross product matrix and take expectations.
jcross = derv_cross ./ dpm;

% Save the output
save jminnerp.mat jcross;

return;
