% ------------------------------------------------------------ %
% PURPOSE:  This program is written primarily to test the code %
%	    for solving the value function and obtaining a set %
%	    of simulated data.  Some parts of this might feed  %
%	    up to another program which will tackle the issue  %
%	    of obtaining Simulated method of moments point     %
%	    estimates.					       %
% ------------------------------------------------------------ %

clear;
addpath ../Model/
addpath ../Simul/
addpath ../Quad/
addpath ../basic

% Initialize the variables of interest
readopt = 1;
if readopt == 1
    load xop;
    theta = xopt(1);
    rho = xopt(2);
    sigma = xopt(3);
    lambda = xopt(4);
    a = xopt(5);
    b = xopt(6);
    gamma = xopt(7);
    fc = xopt(8);
else 
    nu = 0.35811;
    theta = 0.79051;
    mu = -0.30;
    rho = 0.80070;
    sigma = 0.42781;
    lambda = 0.03465;
    a = 9.26452;
    b = 4.12264;
    gamma = 0.18020;
end
mu = -0.30;
alph = 1/3;
nu = alph*(1-theta)/(theta + alph*(1-theta));
sbar = 0.902;

% Other parameters
delta = .165;
beta = 1/1.04;
trat_rd = 31.2/100;
srate = 0.025;

% Panel stuff (keep it small for now)
nFirms = 5176;
nYears = 100;

% Initialize v at zero to start things off
load gmat;
ginit = g; rdinit = r;
clear g r;

% Choose the moments we are matching
mompick = [1 2 4 5 6 7 8 9 10 11 12 15 16];

% Call the value function to solve for firm value
[g, q, qd, i, r, kr, z, kg, w] = ValFun_Mult(theta, nu, mu, rho, sigma, lambda, a, b, ...
                            beta, delta, gamma, fc, trat_rd, sbar, srate, ginit, rdinit);

% Now we can call the simulation program for firms with r&d spending
[zp, kp, qp, ip, rp, dp, pip, pir, sp, yp, sgp, fsp, succ, countz] = ...
         SimPanelMult(g, q, i, r, kr, z, kg, w, nFirms, nYears, theta, nu, mu, rho, ...
                  sigma, lambda, a, b, trat_rd, sbar, beta, delta, gamma, fc, srate);

% Here we can analyse the results by making a combined set of
% policy function matrices
zm = [zp(51:end,:)];
km = [kp(51:end,:)];
im = [ip(51:end,:)];
qm = [qp(51:end,:)];
pim = [pip(51:end,:)];
prm = [pir(51:end,:)];
dm = [dp(51:end,:)];
sm = [succ(51:end,:)];
rpm = [rp(51:end,:)];
rsm = [rp(51:end,:)./yp(51:end,:)];
sgm = [sgp(51:end,:)];
ym = [yp(51:end,:)];
fsm = [fsp(51:end,:)];

% Lets forget about all the stupid stuff and construct the actual
% moments of interest from the simulated data.  

% Do the moments for r&d
fm_rd = mean(vec(rsm));
std_rd = sqrt(mean(vec(rsm.^2)) - fm_rd^2);

% Pick up the sales to capital ratio
fm_sk = mean(vec(ym));

% Do the same for the fixed costs
fm_fs = mean(vec(fsm));

% Do the moments for q
fm_q = mean(vec(qm));

% Do the moments for income after rd
fm_pr = mean(vec(prm));
std_pr = sqrt(mean(vec(prm.^2)) - fm_pr^2);

% Now we want investment
fm_i = mean(vec(im));
std_i = sqrt(mean(vec(im.^2)) - fm_i^2);

% Carry out the regression for income
prdiff = prm;
beta_inc = regress(vec(prdiff(2:end,:)), adc(vec(prdiff(1:end-1,:))));
rho_pr = beta_inc(2);

% Compute the auto-regressive term for r&d
beta_rd = regress(vec(rsm(2:end,:)), adc(vec(rsm(1:end- ...
                                                  1,:))));
rho_rd = beta_rd(2);

% Autoregression for investment
beta_ik = regress(vec(im(2:end,:)), adc(vec(im(1:end-1,:))));
rho_ik = beta_ik(2);

% Pick up a regression of sales growth on R&D
beta_sg = regress(vec(sgm(2:end,:)), adc(vec(rsm(1:end-1,:))));
reg_sg = beta_sg(2);

% Pick up some correlation matrices
co_rdinv = corr(rsm(:), im(:));
co_rdq = corr(rsm(:), qm(:));
co_qi = corr(qm(:), im(:));
co_sglrd = corr(vec(sgm(2:end,:)), vec(rsm(1:end-1,:)));
co_rdk = corr(rsm(:), log(km(:)));

% Put everything together into a big matrix
mom_sim = [fm_rd std_rd fm_sk fm_fs fm_q fm_pr std_pr std_i ...
           rho_pr rho_rd rho_ik co_rdinv co_rdq co_rdk co_qi co_sglrd];

% Load in the moments from the actual data
load ../Data/moments.mat;

% Pick out the moments we want
mom_simp = mom_sim(mompick);
momsp = moms(mompick);
phip = phi(mompick, mompick);

disp 'Actual data moments on r&d, sales, q, earn and inv'
momsp
disp 'Simulated moments'
mom_simp

% Pick up the differences
mom_diff = momsp - mom_simp;
gmm_v = n*mom_diff *inv(n*phip)*mom_diff'

disp 'Moment difference'
mom_diff
disp 'Weighted moment difference'
wgt_diff = (inv(phip)*mom_diff')'
