% ------------------------------------------------------------ %
% PURPOSE:  This program is written to help examine how the    %
%           moments used in the estimation can help identify   %
%           the various parameters of interest in the model.   %
%           In particular, the question we want to address     %
%           relates to the three R&D parameters in the model.  %
%           Effectively, the program creates a vector of       %
%           moments over values for parameters near the values %
%           obtained in the estimation.                        %
% ------------------------------------------------------------ %

clear variables;

% Add all the paths we need
addpath ../Model;
addpath ../Simul;
addpath ../Quad;
addpath ../Data;
addpath ../basic;

% Obviously the first thing to do is to read in the optimum
% parameters.  These are actually read in now.
%theta = 0.4583;
%rho = 0.5727; 
%sig = 0.6040;
%lambda = 0.1714;
%a = 4.9791;
%b = 0.8616;
%gamma = 0.4900;
%fc = 0.4297;

% Put it together
readopt = 1;
if readopt == 1;
    load xop;
    points = xopt';
else
    points = [theta rho sig lambda a b gamma fc];
end
    
% Pick up the guess for mean success rate.
sbar = 0.833;

% Pick up the saved file
load gmat;
ginit = g;

% Load in the parameters from the data;
load ../Data/moments;

mompick = [1 2 4 5 6 7 8 9 10 11 12 15 16];

data_vals{1} = moms(mompick);
data_vals{2} = n;
data_vals{3} = phi(mompick, mompick); 
data_vals{4} = ginit;
data_vals{5} = sbar;

% Define the matrices to be used as inputs
% Set the parameters we do not optimize over
delta = 0.165;
beta = 1/1.04;
srate = 0.025; 

% Here we need to specify tax rates for r&d and non-r&d firms.
trat_rd = 0.312;

% Parameters about the function call to solve for the steady state
sim_ind = 51;  %51

% Panel stuff (keep it small for now)
nFirms = 5176*1;
nYears = 100; 

% Put stuff together;
fix_paras = [beta delta sim_ind nFirms nYears trat_rd srate];

% Now we are ready to do a big funky loop.  Specify a value that
% picks-up the range of parameter values we want to try
epsv = 2.5e-2;

% Select the parameters we want to run this analysis on
selparas = [4 5 7];
nsel = length(selparas);

% Pick up the number of parameter values we are running this over.
% We are going to run this twice, one up and once down to ensure
% that we get the value we want at the starting point.
neval = 50;
epsv_val = epsv/neval;

% This does the forward loop
for i = 1:nsel
    for j = 0:neval
        points(selparas(i)) = points(selparas(i))*(1 + j*epsv_val);
        [gmm_val_f(i,j+1), mom_sim_f(i,j+1,:), diags_f(i,j+1,:), g] = ...
            GMMObj_SA(points, fix_paras, data_vals);
        data_vals{4} = g;
        data_vals{5} = diags_f(i,j+1,2);
        
        % Reinitialize the parameter values
        points = xopt';
        % Try again to get at this more clearly
        % [gmm_val_f(i,j+1), mom_sim_f(i,j+1,:), diags_f(i,j+1,:), g] = ...
        %     GMMObj_SA(points, fix_paras, data_vals);
    end

    % Update the starting values for the next iteration
    data_vals{4} = ginit;
    data_vals{5} = sbar;
    
    %points = [theta rho sig lambda a b gamma fc];

end

% This does the backward loop
for i = 1:nsel
    for j = 0:neval
        points(selparas(i)) = points(selparas(i))*(1 - j*epsv_val);
        [gmm_val_b(i,j+1), mom_sim_b(i,j+1,:), diags_b(i,j+1,:), g] = ...
            GMMObj_SA(points, fix_paras, data_vals);
        data_vals{4} = g;
        data_vals{5} = diags_b(i,j+1,2);
        
        % Reinitialize the parameter values
        points = xopt';
        % Try again to get at this more clearly
        % [gmm_val_b(i,j+1), mom_sim_b(i,j+1,:), diags_b(i,j+1,:), g] = ...
        %     GMMObj_SA(points, fix_paras, data_vals);        
    end

    % Reset the input guess values
    data_vals{4} = ginit;
    data_vals{5} = sbar;

    %points = [theta rho sig lambda a b gamma fc];

end

% This saves the results for us to work with
save identvals;
