function y = myinterp(x,xgrid,ygrid)

%Linear interpolator that lets you "extrapolate" as well
%as interpolate.  Loosely based on John Cochrane's Gauss 
%code.  It works for a vector of functions defined by ygrid.

%ygrid is a numfunc-by-T matrix, xgrid is a row vector of size T. 
%x must be a row vector.  Output is a numfunc-by-length(x)
%matrix.  

if size(xgrid)~=size(ygrid(1,:))
   error('myinterp: xgrid and ygrid do not have the same number of columns')
end

[S,T] = size(xgrid);
[N,M] = size(x);
if N>1 | S>1
   error('myinterp: must have row vectors')
end

numfunc = length(ygrid(:,1));

big_xgrid = ones(numfunc,1)*xgrid;

grad = (ygrid(:,2:T) - ygrid(:,1:T-1))./(big_xgrid(:,2:T) - big_xgrid(:,1:T-1));
intcpt = [ (ygrid(:,1)-grad(:,1).*big_xgrid(:,1)) (ygrid(:,1:T-1)-grad.*big_xgrid(:,1:T-1)) ...
      (ygrid(:,T) - grad(:,T-1).*big_xgrid(:,T))]; 
slope = [grad(:,1) grad grad(:,T-1)];

[Y,I1] = sort([x; xgrid'*ones(size(x))]);

[I2, J] =  find(I1 == 1);

y = intcpt(:,I2) + slope(:,I2).*(ones(numfunc,1)*x);





