%%%%  Function to perform an OLS regression on a given set of data.  The function
%%%%  returns coefficients, their standard errors and the adjusted R_square statistic
%%%%  for the regression.  A Newey-West error correction is planned but not yet 
%%%%  implemented.

%%%  The function takes as inputs two vectos, one of which is a vector of
%%%  the dependant variable, and the other a matrix containing all
%%%  independent variables plus a row of constants if needed.  

%% Written by: Missaka Warusawitharana
%% Last modified: 5/19/04

function [Beta, Std_err, R_Square] = reg(Y,X);

% Obtain the size of the dataset.
T = size(X,1);

% Compute the regression coefficients
H = X'*X;
XY = X'*Y;
Beta = inv(H)*XY;

% Compute the basic OLS standard errors
epsil = Y - X*Beta;
eps_cov = epsil'*epsil/T;

Sigma = eps_cov*inv(H);
Std_err = diag(sqrt(Sigma));

% Compute the adjusted R-square for the regression.
% M = X*inv(H)*X';  % This particular matrix is too big
Y_b = mean(Y);

R_Square = (XY'*inv(H)*XY-T*Y_b^2)/(Y'*Y-T*Y_b^2);

